==> xmms-singit_0.1.27.orig.tar.gz: xmms-singit-0.1.27/src/editor/editor_config.h <==
/*
 *  SingIt Lyrics Displayer
 *  Copyright (C) 2000 - 2002 Jan-Marek Glogowski <glogow@stud.fbi.fh-darmstadt.de>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */


#ifndef __DISPLAYER_EDITOR_CONFIG_H__
#define __DISPLAYER_EDITOR_CONFIG_H__

#include "singit_config_gen.h"

#ifdef __cplusplus
extern "C" {
#endif // __cplusplus

typedef struct _EditorConfigData {

	// From lyrics editor
	gboolean     multiSelect;
	gboolean     showHints;
	gboolean     extendedLyrics;
	gboolean     checkSyncBeforeSave;
	gint         reactionTime;
	gint         underscoreWhiteTransform;
	gint         stripHtml;

	// Changed by plugin dialogs - restored
	gint         winPosX;
	gint         winPosY;
}
EditorConfigData;

SingitConfigGen *editor_config_new(void);

#define GET_ECD(x) ((EditorConfigData *) singit_config_gen_get_data(SINGIT_CONFIG_GEN(x)))

#ifdef __cplusplus
}
#endif // __cplusplus

#endif  // __DISPLAYER_EDITOR_CONFIG_H__

==> xmms-singit_0.1.28.orig.tar.gz: xmms-singit-0.1.28.orig/src/editor/editor_config.h <==
/*
 *  SingIt Lyrics Displayer
 *  Copyright (C) 2000 - 2002 Jan-Marek Glogowski <glogow@stud.fbi.fh-darmstadt.de>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */


#ifndef __DISPLAYER_EDITOR_CONFIG_H__
#define __DISPLAYER_EDITOR_CONFIG_H__

#include "singit/config_xmms.h"

#ifdef HAVE_QUERY_DEPS
#include "editor_query_http.h"
#endif

#ifdef __cplusplus
extern "C" {
#endif // __cplusplus

typedef struct _EditorConfigData {

	gboolean     multiSelect;
	gboolean     showHints;
	gboolean     extendedLyrics;
	gboolean     checkSyncBeforeSave;
	gint         reactionTime;
	gint         underscoreWhiteTransform;
	gint         stripHtml;

#ifdef HAVE_QUERY_DEPS
	SearchMatch  artistMatch;
	SearchMatch  titleMatch;
#endif

	gint         winPosX;
	gint         winPosY;
}
EditorConfigData;

SingitConfigGen* editor_config_new(void);

#define GET_ECD ((EditorConfigData *) \
	singit_config_gen_get_data(EDT_STATUS->config))

#ifdef __cplusplus
}
#endif // __cplusplus

#endif  // __DISPLAYER_EDITOR_CONFIG_H__
